==> jodd-all-4.3.0-sources.jar: jodd/http/HttpConnectionProvider.java <==
// Copyright (c) 2003-present, Jodd Team (http://jodd.org)
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

package jodd.http;

import java.io.IOException;

/**
 * Factory for {@link HttpConnection http connections}.
 */
public interface HttpConnectionProvider {

	/**
	 * Specifies {@link ProxyInfo proxy} for provide to use.
	 */
	public void useProxy(ProxyInfo proxyInfo);

 	/**
	 * Creates new {@link HttpConnection}
	 * from {@link jodd.http.HttpRequest request}.
	 */
	public HttpConnection createHttpConnection(HttpRequest httpRequest) throws IOException;

}

==> jodd-all-5.0.5-sources.jar: jodd/http/HttpConnectionProvider.java <==
// Copyright (c) 2003-present, Jodd Team (http://jodd.org)
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

package jodd.http;

import jodd.http.net.SocketHttpConnectionProvider;

import java.io.IOException;

/**
 * Factory for {@link HttpConnection http connections}.
 */
public interface HttpConnectionProvider {

	class Implementation {
		private static HttpConnectionProvider httpConnectionProvider = new SocketHttpConnectionProvider();

		public static void set(final HttpConnectionProvider httpConnectionProvider) {
			Implementation.httpConnectionProvider = httpConnectionProvider;
		}
	}

	/**
	 * Returns default implementation of connection provider.
	 */
	static HttpConnectionProvider get() {
		return Implementation.httpConnectionProvider;
	}


	/**
	 * Specifies {@link ProxyInfo proxy} for provide to use.
	 */
	public void useProxy(ProxyInfo proxyInfo);

	/**
	 * Creates new {@link HttpConnection}
	 * from {@link jodd.http.HttpRequest request}.
	 */
	public HttpConnection createHttpConnection(HttpRequest httpRequest) throws IOException;

}
